pub struct RuleCV09 {
pub blocked_words: Vec<String>,
}Expand description
CV09: Use of blocked words.
Flag identifiers that match a configurable list of blocked words.
Fields
blocked_words: Vec<String>Trait Implementations
Sourceimpl Rule for RuleCV09
impl Rule for RuleCV09
Sourcefn description(&self) -> &'static str
fn description(&self) -> &'static str
One-line description.
Sourcefn explanation(&self) -> &'static str
fn explanation(&self) -> &'static str
Multi-sentence explanation for AI consumers.
Sourcefn is_fixable(&self) -> bool
fn is_fixable(&self) -> bool
Can this rule auto-fix violations?
Sourcefn configure(&mut self, settings: &HashMap<String, String>)
fn configure(&mut self, settings: &HashMap<String, String>)
Configure the rule with key-value settings from config.
Default implementation is a no-op.
Sourcefn crawl_type(&self) -> CrawlType
fn crawl_type(&self) -> CrawlType
Which segments should be visited.
Sourcefn eval(&self, ctx: &RuleContext<'_>) -> Vec<LintViolation>
fn eval(&self, ctx: &RuleContext<'_>) -> Vec<LintViolation>
Evaluate the rule at the given context, returning violations.