pub struct RuleRF02;Expand description
RF02: Column references should be qualified when multiple tables are present.
When a SELECT statement references multiple tables (via FROM + JOINs), all column references should be qualified with a table alias or name to avoid ambiguity.