RuleRF05

Struct RuleRF05 

pub struct RuleRF05;
RF05: Identifiers should not contain special characters.

Bare identifiers should only contain alphanumeric characters and underscores. QuotedIdentifiers are excluded from this check as they may legitimately need special characters.