pub fn is_in_table_context(ctx: &RuleContext<'_>) -> boolExpand description
Check if the current rule context is a table alias (parent is FROM or JOIN clause).
pub fn is_in_table_context(ctx: &RuleContext<'_>) -> boolCheck if the current rule context is a table alias (parent is FROM or JOIN clause).