pub struct RuleRF05;Expand description
RF05: Identifiers should not contain special characters.
Bare identifiers should only contain alphanumeric characters and underscores. QuotedIdentifiers are excluded from this check as they may legitimately need special characters.